//LabPlot : DifferencesListDialog.h

#ifndef DIFFERENCESLISTDIALOG_H
#define DIFFERENCESLISTDIALOG_H

#include "ListDialog.h"

class DifferencesListDialog : public ListDialog
{
	Q_OBJECT
public:
	DifferencesListDialog(MainWin *mw, const char *name);
public slots:
private slots:
	int apply_clicked();
};

#endif // DIFFERENCESLISTDIALOG_H
